@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Persistence;
 
+use BadMethodCallException;
 use Doctrine\Persistence\Mapping\ClassMetadata;
 use Doctrine\Persistence\Mapping\ClassMetadataFactory;
 use Doctrine\Persistence\ObjectManager;
@@ -155,12 +156,43 @@ class ObjectManagerDecoratorTest extends TestCase
 
         self::assertTrue($this->decorated->contains($object));
     }
+
+    /** @requires PHP 8.0 */
+    public function testIsUninitializedObject(): void
+    {
+        $object = new TestObject();
+
+        $wrapped   = $this->createMock(ObjectManagerV4::class);
+        $decorated = new NullObjectManagerDecorator($wrapped);
+        $wrapped->expects(self::once())
+            ->method('isUninitializedObject')
+            ->with($object)
+            ->willReturn(false);
+
+        self::assertFalse($decorated->isUninitializedObject($object));
+    }
+
+    /** @requires PHP 8.0 */
+    public function testIsThrowsWhenTheWrappedObjectManagerDoesNotImplementObjectManagerV4(): void
+    {
+        $object = new TestObject();
+
+        $this->expectException(BadMethodCallException::class);
+        $decorated = new NullObjectManagerDecorator($this->createMock(ObjectManager::class));
+
+        self::assertFalse($decorated->isUninitializedObject($object));
+    }
+}
+
+interface ObjectManagerV4 extends ObjectManager
+{
+    public function isUninitializedObject(mixed $object): bool;
 }
 
 /** @extends ObjectManagerDecorator<ObjectManager&MockObject> */
 class NullObjectManagerDecorator extends ObjectManagerDecorator
 {
-    /** @psalm-param ObjectManager&MockObject $wrapped */
+    /** @phpstan-param ObjectManager&MockObject $wrapped */
     public function __construct(ObjectManager $wrapped)
     {
         $this->wrapped = $wrapped;
